@@ -5,6 +5,7 @@ Created on:    Nov 10, 2013
 '''
 import os
 import glob
+from csscompressor import compress
 
 def purifylines(text):
     return [ j for j in 
@@ -49,3 +50,5 @@ def get_source_dirs(sources):
             
     return sorted(distinct(source_dirs))
 
+def minify(css):
+    return compress(css)
