@@ -34,7 +34,7 @@ class IsassEventHandler(FileSystemEventHandler):
 
             compiler = SassCompiler(lib_dirs=lib_dirs)
             for sf in self.source_files:
-                print "Reading %s" % os.path.abspath(sf)
+                #print "Reading %s" % os.path.abspath(sf)
                 compiler.read_file(sf)
 
 
